@@ -21,7 +21,7 @@ from .util import (
     read_config,
 )
 
-__version__ = "0.10.0"
+__version__ = "0.10.1"
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -79,7 +79,9 @@ class Connection:
                 return res
         except Exception as error:
             _LOGGER.warning(
-                "Failure when communcating with the server: %s", error
+                "Failure when communicating with the server: %s",
+                error,
+                exc_info=True,
             )
             raise
 
